=========================
Vitrage CLI Documentation
=========================

In this section you will find information on Vitrage’s command line
interface.

.. toctree::
   :maxdepth: 1

   vitrage-status
   vitrage-purge-data